@@ -26,7 +26,7 @@ impl TryFrom<f64> for Longitude {
         if item >= -180.0 && item <= 180.0 {
             Ok(Self(Angle::from_deg(item)))
         } else {
-            Err(format_err!("{} is not a valid longitude", item))
+            Err(format_err!("{item} is not a valid longitude"))
         }
     }
 }
